@@ -506,7 +506,7 @@ class XVG(utilities.FileUtils):
                     row = [float(el) for el in line.split()]
                 except:
                     if self.permissive:
-                        self.logger.warn("%s: SKIPPING unparsable line %d: %r",
+                        self.logger.warning("%s: SKIPPING unparsable line %d: %r",
                                          self.real_filename, lineno+1, line)
                         self.corrupted_lineno.append(lineno+1)
                         continue
@@ -516,7 +516,7 @@ class XVG(utilities.FileUtils):
                 # check for same number of columns as in previous step
                 if ncol is not None and len(row) != ncol:
                     if self.permissive:
-                        self.logger.warn("%s: SKIPPING line %d with wrong number of columns: %r",
+                        self.logger.warning("%s: SKIPPING line %d with wrong number of columns: %r",
                                          self.real_filename, lineno+1, line)
                         self.corrupted_lineno.append(lineno+1)
                         continue
@@ -1160,7 +1160,7 @@ class XVG(utilities.FileUtils):
         if not 'savedata' in d:
             wmsg = "Reading pre 0.1.13 pickle file: setting savedata=False"
             warnings.warn(wmsg, category=DeprecationWarning)
-            self.logger.warn(wmsg)
+            self.logger.warning(wmsg)
             d['savedata'] = False  # new default
         self.__dict__.update(d)
 
@@ -1200,7 +1200,7 @@ def break_array(a, threshold=numpy.pi, other=None):
     b = numpy.empty((len(a) + m))
     # calculate new indices for breaks in b, taking previous insertions into account
     b_breaks = breaks + numpy.arange(m)
-    mask =  numpy.zeros_like(b, dtype=numpy.bool)
+    mask =  numpy.zeros_like(b, dtype=bool)
     mask[b_breaks] = True
     b[~mask] = a
     b[mask] = numpy.NAN
